# Mailiness

Manage your mail server at the command line.

## Features

- Manage virtual users, domains, and aliases using a SQLite database.
- Generate DKIM Key pairs.

Documentation - https://mailiness.readthedocs.io/en/latest/
